@@ -1,26 +1,23 @@
 package Galileo::Admin;
 use Mojo::Base 'Mojolicious::Controller';
-use Mojo::JSON 'j';
 
 sub users { shift->render }
 sub pages { shift->render }
-sub user { shift->render }
+sub user  { shift->render }
 
 sub store_user {
   my $self = shift;
-  $self->on( text => sub {
-    my ($self, $message) = @_;
-
-    my $data = j($message);
+  $self->on( json => sub {
+    my ($self, $data) = @_;
 
     my $pass1 = delete $data->{pass1};
     my $pass2 = delete $data->{pass2};
     if ( $pass1 or $pass2 ) {
       unless ( $pass1 eq $pass2 ) {
-        $self->send({ text => j({ 
+        $self->send({ json => { 
           message => 'Not saved! Passwords do not match', 
           success => \0,
-        }) });
+        } });
         return 0;
       }
       $data->{password} = $pass1;
@@ -28,10 +25,10 @@ sub store_user {
 
     my $rs = $self->schema->resultset('User');
     unless ( $rs->single({ name => $data->{name} }) or $data->{password}) {
-      $self->send({ text => j({ 
+      $self->send({ json => { 
         message => 'Cannot create user without a password',
         success => \0, 
-      }) });
+      } });
       return 0;
     }
 
@@ -40,35 +37,35 @@ sub store_user {
     $rs->update_or_create(
       $data, {key => 'users_name'},
     );
-    $self->send({ text => j({
+    $self->send({ json => {
       message => 'Changes saved',
       success => \1,
-    }) });
+    } });
   });
 }
 
 sub remove_page {
   my $self = shift;
 
-  $self->on( text => sub {
-    my ($self, $message) = @_;
-    my $id = j($message)->{id};
+  $self->on( json => sub {
+    my ($self, $data) = @_;
+    my $id = $data->{id};
 
     if ($id == 1) {
-      $self->send({ text => j({
+      $self->send({ json => {
         success => \0,
         message => 'Cannot remove home page',
-      }) });
+      } });
       return;
     }
 
     my $page = $self->schema->resultset('Page')->single({ page_id => $id });
 
     unless ( $page ) {
-      $self->send({ text => j({
+      $self->send({ json => {
         success => \0,
         message => "Could not access page (id $id)",
-      }) });
+      } });
       return;
     }
 
@@ -76,17 +73,17 @@ sub remove_page {
     #TODO remove page from nav menu if present
 
     unless ( $affected ) {
-      $self->send({ text => j({
+      $self->send({ json => {
         success => \0,
         message => 'Database reports failure on deleting page',
-      }) });
+      } });
       return;
     }
 
-    $self->send({ text => j({
+    $self->send({ json => {
       success => \1,
       message => 'Page removed',
-    }) });
+    } });
     return;
 
   });
