@@ -132,10 +132,9 @@ sub run {
 
     $self->humane_stash( 'Goodbye' );
     $self->render('galileo_finish');
+    $self->tx->on( finish => sub { exit } );
   });
 
-  $r->any('/exit' => sub { exit });
-
   $self->Mojolicious::Command::daemon::run(@args);
 }
 
@@ -269,10 +268,6 @@ __DATA__
   <p>Setup complete, run <pre>$ galileo daemon</pre></p>
 % }
 
-%= javascript begin
-  $(function(){ $.get('<%= url_for 'exit' %>') });
-% end
-
 @@ control_group.html.ep
 
 <div class="control-group">
